# Changelog

All notable changes to this project will be documented in this file.

## [0.2.0](https://github.com/ben-ranford/cellin/compare/cellin-v0.1.1...cellin-v0.2.0) (2026-04-05)


### Features

* **ingest:** add multimodal ingestion and local stores ([#15](https://github.com/ben-ranford/cellin/issues/15)) ([671e0ae](https://github.com/ben-ranford/cellin/commit/671e0aeda51cfd5df9a30bc9fa4c185a24c1958f))


### Bug Fixes

* **cli:** respect zero trace limit ([#51](https://github.com/ben-ranford/cellin/issues/51)) ([e1e1e10](https://github.com/ben-ranford/cellin/commit/e1e1e10bff06309c64e8ea2fb02b91a09f43bc89))
* **dreaming:** align abstraction token counts ([#49](https://github.com/ben-ranford/cellin/issues/49)) ([9d6c39e](https://github.com/ben-ranford/cellin/commit/9d6c39e6e861f25700add2046db6a2ae1f979af1))
* **evals:** relax float comparisons ([#53](https://github.com/ben-ranford/cellin/issues/53)) ([#60](https://github.com/ben-ranford/cellin/issues/60)) ([4c90a35](https://github.com/ben-ranford/cellin/commit/4c90a3510c065b68368e72ded1ffab6e87dfd558))
* **release:** harden rolling release inputs ([#52](https://github.com/ben-ranford/cellin/issues/52)) ([#59](https://github.com/ben-ranford/cellin/issues/59)) ([fd3bf65](https://github.com/ben-ranford/cellin/commit/fd3bf65cc093d4fd23a9d7f16fcc4de9f7c7845e))


### Documentation

* **readme:** add release badges ([#47](https://github.com/ben-ranford/cellin/issues/47)) ([12ee8cb](https://github.com/ben-ranford/cellin/commit/12ee8cb99631fb2c79243125797d53f123bf1af9))
* **readme:** link PyPI install ([#48](https://github.com/ben-ranford/cellin/issues/48)) ([54e83c6](https://github.com/ben-ranford/cellin/commit/54e83c608a01bd0fda6255dcecb549c6cb60d02b))

## [0.1.1] - 2026-04-05

### Bootstrap

- Established the public library release surface and automated stable release baseline for future release-please-managed cuts.
